__all__ = ()

EMPTY = 'EMPTY'
NEW = 'NEW'
IN_PROCESS = 'INPR'
SUCCESS = 'SCS'
ERROR = 'ERR'
FAILURE = 'FAIL'
CANCEL = 'CANCEL'
RETRY = 'RETRY'
